=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2005-10-16 21:51:55 +0000
+++ bzrlib/branch.py	2005-10-16 22:04:54 +0000
@@ -64,32 +64,6 @@
     # XXX: leave this here for about one release, then remove it
     raise NotImplementedError('find_branch() is not supported anymore, '
                               'please use one of the new branch constructors')
-def _relpath(base, path):
-    """Return path relative to base, or raise exception.
-
-    The path may be either an absolute path or a path relative to the
-    current working directory.
-
-    Lifted out of Branch.relpath for ease of testing.
-
-    os.path.commonprefix (python2.4) has a bad bug that it works just
-    on string prefixes, assuming that '/u' is a prefix of '/u2'.  This
-    avoids that problem."""
-    rp = os.path.abspath(path)
-
-    s = []
-    head = rp
-    while len(head) >= len(base):
-        if head == base:
-            break
-        head, tail = os.path.split(head)
-        if tail:
-            s.insert(0, tail)
-    else:
-        raise NotBranchError("path %r is not within branch %r" % (rp, base))
-
-    return os.sep.join(s)
-        
 
 ######################################################################
 # branch objects
@@ -377,16 +351,22 @@
             self._lock_mode = self._lock_count = None
 
     def abspath(self, name):
-        """Return absolute filename for something in the branch"""
+        """Return absolute filename for something in the branch
+        
+        XXX: Robert Collins 20051017 what is this used for? why is it a branch
+        method and not a tree method.
+        """
         return self._transport.abspath(name)
 
     def relpath(self, path):
         """Return path relative to this branch of something inside it.
 
-        Raises an error if path is not in this branch."""
+        Raises an error if path is not in this branch.
+        XXX: Robert Collins 20051017 what is this used for? why is it a branch
+        method and not a tree method.
+        """
         return self._transport.relpath(path)
 
-
     def _rel_controlfilename(self, file_or_path):
         if isinstance(file_or_path, basestring):
             file_or_path = [file_or_path]

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2005-10-15 11:38:29 +0000
+++ bzrlib/osutils.py	2005-10-16 22:04:54 +0000
@@ -30,7 +30,7 @@
 import types
 
 import bzrlib
-from bzrlib.errors import BzrError
+from bzrlib.errors import BzrError, NotBranchError
 from bzrlib.trace import mutter
 
 
@@ -437,3 +437,30 @@
             return True
     else:
         return False
+
+
+def relpath(base, path):
+    """Return path relative to base, or raise exception.
+
+    The path may be either an absolute path or a path relative to the
+    current working directory.
+
+    os.path.commonprefix (python2.4) has a bad bug that it works just
+    on string prefixes, assuming that '/u' is a prefix of '/u2'.  This
+    avoids that problem."""
+    rp = os.path.abspath(path)
+
+    s = []
+    head = rp
+    while len(head) >= len(base):
+        if head == base:
+            break
+        head, tail = os.path.split(head)
+        if tail:
+            s.insert(0, tail)
+    else:
+        # XXX This should raise a NotChildPath exception, as its not tied
+        # to branch anymore.
+        raise NotBranchError("path %r is not within branch %r" % (rp, base))
+
+    return os.sep.join(s)

=== modified file 'bzrlib/selftest/whitebox.py'
--- bzrlib/selftest/whitebox.py	2005-10-13 04:32:44 +0000
+++ bzrlib/selftest/whitebox.py	2005-10-16 22:04:54 +0000
@@ -108,11 +108,11 @@
     def test_relpath(self):
         """test for branch path lookups
     
-        Branch.relpath and bzrlib.branch._relpath do a simple but subtle
+        bzrlib.osutils._relpath do a simple but subtle
         job: given a path (either relative to cwd or absolute), work out
         if it is inside a branch and return the path relative to the base.
         """
-        from bzrlib.branch import _relpath
+        from bzrlib.osutils import relpath
         import tempfile, shutil
         
         savedir = os.getcwdu()
@@ -121,7 +121,7 @@
         dtmp = os.path.realpath(dtmp)
 
         def rp(p):
-            return _relpath(dtmp, p)
+            return relpath(dtmp, p)
         
         try:
             # check paths inside dtmp while standing outside it

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2005-10-13 04:02:48 +0000
+++ bzrlib/transport/local.py	2005-10-16 22:04:54 +0000
@@ -59,8 +59,8 @@
     def relpath(self, abspath):
         """Return the local path portion from a given absolute path.
         """
-        from bzrlib.branch import _relpath
-        return _relpath(self.base, abspath)
+        from bzrlib.osutils import relpath
+        return relpath(self.base, abspath)
 
     def has(self, relpath):
         return os.access(self.abspath(relpath), os.F_OK)

